<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class PubMed_Citations_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	 private $qs; //hack for now - will figure out a better way to do this in the future

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

		function pubmed_cite_options_page_html(){
	?>
	  <div class='wrap'>
	  <form action='options.php' method='post'>
  	<?php
	  settings_fields( 'pubmed_cite_options' );
	  do_settings_sections( 'pubmed_citations' );
	  submit_button( 'Save' );
  	?>
	  </form>
	  </div>
  	<?php
	}

	function pubmed_cite_register_settings() {
		register_setting( 'pubmed_cite_options', 'pubmed_cite_options',[$this,'pubmed_cite_options_validate'] );
		add_settings_section( 'api_settings', 'PubMed Citations API Settings', [$this,'pubmed_cite_section_text'], 'pubmed_citations' );

		add_settings_field( 'pubmed_cite_setting_api_key', 'API Key', [$this,'pubmed_cite_setting_api_key'], 'pubmed_citations', 'api_settings' );
		add_settings_field( 'pubmed_cite_setting_intro', 'List Introduction', [$this,'pubmed_cite_setting_intro'], 'pubmed_citations', 'api_settings' );
    add_settings_field( 'pubmed_cite_setting_querystring_1', 'Query String 1', [$this,'pubmed_cite_setting_querystring_1'], 'pubmed_citations', 'api_settings' );
    add_settings_field( 'pubmed_cite_setting_querystring_2', 'Query String 2', [$this,'pubmed_cite_setting_querystring_2'], 'pubmed_citations', 'api_settings' );
    add_settings_field( 'pubmed_cite_setting_querystring_3', 'Query String 3', [$this,'pubmed_cite_setting_querystring_3'], 'pubmed_citations', 'api_settings' );
    add_settings_field( 'pubmed_cite_setting_querystring_4', 'Query String 4', [$this,'pubmed_cite_setting_querystring_4'], 'pubmed_citations', 'api_settings' );
    add_settings_field( 'pubmed_cite_setting_querystring_5', 'Query String 5', [$this,'pubmed_cite_setting_querystring_5'], 'pubmed_citations', 'api_settings' );

		add_settings_field( 'pubmed_cite_setting_pmc', 'PubMed Central', [$this,'pubmed_cite_setting_pmc'], 'pubmed_citations', 'api_settings' );
		add_settings_field( 'pubmed_cite_setting_pm', 'PubMed', [$this,'pubmed_cite_setting_pm'], 'pubmed_citations', 'api_settings' );
	}

	function pubmed_cite_section_text() {
    echo "<p>Here you can set all the options for accessing the PubMed API. The API Key is required. Click <a href='https://support.nlm.nih.gov/knowledgebase/article/KA-05317/en-us'>here</a> to obtain an API key from NCBI.</p>
    <p>Query strings are very basic. Each field is treated within an OR statement. For example, if multiple query strings are submitted, the plugin will search for [query string 1] OR [query string 2]. It doesn't get more complex than that.</p>
    <p>Be sure to check which repositories (PubMed or PubMed Central) you wish to have searched.</p>
    <p>The List Introduction field can contain HTML code if desired.</p>
    <p>Plugin is activated with a short code. Place [pubmed-citations] on any page on which the list should appear.</p>
    ";
}

	function pubmed_cite_options_validate($input){
		$newinput['api_key'] = trim( $input['api_key'] );
		$newinput['intro'] = trim( $input['intro'] );
		$newinput['querystring_1'] = trim( $input['querystring_1'] );
		$newinput['querystring_2'] = trim( $input['querystring_2'] );
		$newinput['querystring_3'] = trim( $input['querystring_3'] );
		$newinput['querystring_4'] = trim( $input['querystring_4'] );
		$newinput['querystring_5'] = trim( $input['querystring_5'] );
		$newinput['pmc'] = $input['pmc'];
		$newinput['pm'] = $input['pm'];

		return $newinput;
	}

  function pubmed_cite_options_page(){
      add_submenu_page(
        'tools.php',
        'PubMed Citations Options',
        'PubMed Citations',
        'manage_options',
        'pubmed-citations-menu',
        [$this,'pubmed_cite_options_page_html']
      );

  }

	function pubmed_cite_setting_api_key() {
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['api_key'])){
			echo "<input id='pubmed_cite_setting_api_key' name='pubmed_cite_options[api_key]' type='text' value='".esc_attr( $options['api_key'] ). "' />";
		  } else {
			echo "<input id='pubmed_cite_setting_api_key' name='pubmed_cite_options[api_key]' type='text' value='' />";
		  }
	}

	function pubmed_cite_setting_intro() {
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['intro'])){
			echo "<textarea id='pubmed_cite_setting_intro' name='pubmed_cite_options[intro]' >".esc_attr( $options['intro'] ). "</textarea />";
		  } else {
			echo "<textarea id='pubmed_cite_setting_intro' name='pubmed_cite_options[intro]' type='text' ></textarea/>";
		  }
	}

	function pubmed_cite_setting_querystring_1(){
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['querystring_1'])){
			echo "<input id='pubmed_cite_setting_query_string_1' name='pubmed_cite_options[querystring_1]' type='text' value='".esc_attr( $options['querystring_1'] ). "' />";
		  } else {
			echo "<input id='pubmed_cite_setting_query_string_1' name='pubmed_cite_options[querystring_1]' type='text' value='' />";
		  }
	}

	function pubmed_cite_setting_querystring_2(){
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['querystring_2'])){
			echo "<input id='pubmed_cite_setting_query_string_2' name='pubmed_cite_options[querystring_2]' type='text' value='".esc_attr( $options['querystring_2'] ). "' />";
		  } else {
			echo "<input id='pubmed_cite_setting_query_string_2' name='pubmed_cite_options[querystring_2]' type='text' value='' />";
		  }
	}

	function pubmed_cite_setting_querystring_3(){
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['querystring_3'])){
			echo "<input id='pubmed_cite_setting_query_string_3' name='pubmed_cite_options[querystring_3]' type='text' value='".esc_attr( $options['querystring_3'] ). "' />";
		  } else {
			echo "<input id='pubmed_cite_setting_query_string_3' name='pubmed_cite_options[querystring_3]' type='text' value='' />";
		  }
	}

		function pubmed_cite_setting_querystring_4(){
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['querystring_4'])){
			echo "<input id='pubmed_cite_setting_query_string_4' name='pubmed_cite_options[querystring_4]' type='text' value='".esc_attr( $options['querystring_4'] ). "' />";
		  } else {
			echo "<input id='pubmed_cite_setting_query_string_4' name='pubmed_cite_options[querystring_4]' type='text' value='' />";
		  }
	}

		function pubmed_cite_setting_querystring_5(){
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['querystring_5'])){
			echo "<input id='pubmed_cite_setting_query_string_5' name='pubmed_cite_options[querystring_5]' type='text' value='".esc_attr( $options['querystring_5'] ). "' />";
		  } else {
			echo "<input id='pubmed_cite_setting_query_string_5' name='pubmed_cite_options[querystring_5]' type='text' value='' />";
		  }
	}

	function pubmed_cite_setting_pmc() {
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['pmc'])){
			echo "<input id='pubmed_cite_setting_pmc' name='pubmed_cite_options[pmc]' type='checkbox' value='1' ". checked( 1, $options['pmc'], false ) ."/>";
		  } else {
			echo "<input id='pubmed_cite_setting_pmc' name='pubmed_cite_options[pmc]' type='checkbox' value='1' />";
		  }
	}

	function pubmed_cite_setting_pm() {
		$options = get_option( 'pubmed_cite_options' );
		 if(!empty($options['pm'])){
			echo "<input id='pubmed_cite_setting_pm' name='pubmed_cite_options[pm]' type='checkbox' value='1' ". checked( 1, $options['pm'], false ) ."/>";
		  } else {
			echo "<input id='pubmed_cite_setting_pm' name='pubmed_cite_options[pm]' type='checkbox' value='1' />";
		  }
	}


	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/plugin-name-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/plugin-name-admin.js', array( 'jquery' ), $this->version, false );

	}

}
