<?php
/**
 * Plugin Name: PubMed Citations
 * Plugin URI: https://vbrn.org
 * Description: Return all publications from PubMed and PubMedCentral sites based on identifiers
 * Version: 0.2
 * Text Domain: pubmed-cite
 * Author: Nate Herzog
 * Author URI: https://vbrn.org
 */


 // If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '0.2.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-plugin-name-activator.php
 */
function activate_plugin_name() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/pubmed-cite-activator.php';
	PubMed_Citations_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-plugin-name-deactivator.php
 */
function deactivate_plugin_name() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/pubmed-cite-deactivator.php';
	PubMed_Citations_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_plugin_name' );
register_deactivation_hook( __FILE__, 'deactivate_plugin_name' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */

require plugin_dir_path( __FILE__ ) . 'includes/pubmed-cite-class.php';

//run the damn plugin
pubmed_citations();

function pubmed_citations(){
  //run command

  $plugin = new pubmed_citations();
  $plugin->run();

 // return $plugin->query_pubmed();
}

///testing below - all copied from admin class

//note - deleted pubmed_cite_options_page_html for comment/log reasons

//
// 	function pubmed_cite_register_settings() {
// 		register_setting( 'pubmed_cite_options', 'pubmed_cite_options','pubmed_cite_options_validate' );
// 		add_settings_section( 'api_settings', 'API Settings', 'pubmed_cite_section_text', 'pubmed_citations' );
//
// 		add_settings_field( 'pubmed_cite_setting_api_key', 'API Key', 'pubmed_cite_setting_api_key', 'pubmed_citations', 'api_settings' );
//     add_settings_field( 'pubmed_cite_setting_querystring_1', 'Query String 1', 'pubmed_cite_setting_querystring_1', 'pubmed_citations', 'api_settings' );
//     add_settings_field( 'pubmed_cite_setting_querystring_2', 'Query String 2', 'pubmed_cite_setting_querystring_2', 'pubmed_citations', 'api_settings' );
//     add_settings_field( 'pubmed_cite_setting_querystring_3', 'Query String 3', 'pubmed_cite_setting_querystring_3', 'pubmed_citations', 'api_settings' );
// 		add_settings_field( 'pubmed_cite_setting_pmc', 'PubMed Central', 'pubmed_cite_setting_pmc', 'pubmed_citations', 'api_settings' );
// 		add_settings_field( 'pubmed_cite_setting_pm', 'PubMed', 'pubmed_cite_setting_pm', 'pubmed_citations', 'api_settings' );
// 	}
//
// 	function pubmed_cite_section_text() {
//     echo "<p>Here you can set all the options for accessing the PubMed API. The API Key is required. Click <a href='https://support.nlm.nih.gov/knowledgebase/article/KA-05317/en-us'>here</a> to obtain an API key from NCBI.</p>
//     <p>Query strings are very basic. Each field is treated within an OR statement. For example, if multiple query strings are submitted, the plugin will search for [query string 1] OR [query string 2]. It doesn't get more complex than that.</p>
//     <p>Be sure to check which repositories (PubMed or PubMed Central)you wish to have searched.</p>
//     ";
// }
//
// 	function pubmed_cite_options_validate($input){
// 		$newinput['api_key'] = trim( $input['api_key'] );
// 		$newinput['querystring_1'] = trim( $input['querystring_1'] );
// 		$newinput['querystring_2'] = trim( $input['querystring_2'] );
// 		$newinput['querystring_3'] = trim( $input['querystring_3'] );
// 		$newinput['pmc'] = $input['pmc'];
// 		$newinput['pm'] = $input['pm'];
//
// 		return $newinput;
// 	}
//
//   function pubmed_cite_options_page(){
//       add_submenu_page(
//         'tools.php',
//         'PubMed Citations Options',
//         'PubMed Citations',
//         'manage_options',
//         'pubmed-citations-menu',
//         'pubmed_cite_options_page_html'
//       );
//
//   }
//
// 	function pubmed_cite_setting_api_key() {
// 		$options = get_option( 'pubmed_cite_options' );
// 		 if(!empty($options['api_key'])){
// 			echo "<input id='pubmed_cite_setting_api_key' name='pubmed_cite_options[api_key]' type='text' value='".esc_attr( $options['api_key'] ). "' />";
// 		  } else {
// 			echo "<input id='pubmed_cite_setting_api_key' name='pubmed_cite_options[api_key]' type='text' value='' />";
// 		  }
// 	}
//
// 	function pubmed_cite_setting_querystring_1(){
// 		$options = get_option( 'pubmed_cite_options' );
// 		 if(!empty($options['querystring_1'])){
// 			echo "<input id='pubmed_cite_setting_query_string_1' name='pubmed_cite_options[querystring_1]' type='text' value='".esc_attr( $options['querystring_1'] ). "' />";
// 		  } else {
// 			echo "<input id='pubmed_cite_setting_query_string_1' name='pubmed_cite_options[querystring_1]' type='text' value='' />";
// 		  }
// 	}
//
// 	function pubmed_cite_setting_querystring_2(){
// 		$options = get_option( 'pubmed_cite_options' );
// 		 if(!empty($options['querystring_2'])){
// 			echo "<input id='pubmed_cite_setting_query_string_2' name='pubmed_cite_options[querystring_2]' type='text' value='".esc_attr( $options['querystring_2'] ). "' />";
// 		  } else {
// 			echo "<input id='pubmed_cite_setting_query_string_2' name='pubmed_cite_options[querystring_2]' type='text' value='' />";
// 		  }
// 	}
//
// 	function pubmed_cite_setting_querystring_3(){
// 		$options = get_option( 'pubmed_cite_options' );
// 		 if(!empty($options['querystring_3'])){
// 			echo "<input id='pubmed_cite_setting_query_string_3' name='pubmed_cite_options[querystring_3]' type='text' value='".esc_attr( $options['querystring_3'] ). "' />";
// 		  } else {
// 			echo "<input id='pubmed_cite_setting_query_string_3' name='pubmed_cite_options[querystring_3]' type='text' value='' />";
// 		  }
// 	}
//
// 	function pubmed_cite_setting_pmc() {
// 		$options = get_option( 'pubmed_cite_options' );
// 		 if(!empty($options['pmc'])){
// 			echo "<input id='pubmed_cite_setting_pmc' name='pubmed_cite_options[pmc]' type='checkbox' value='1' ". checked( 1, $options['pmc'], false ) ."/>";
// 		  } else {
// 			echo "<input id='pubmed_cite_setting_pmc' name='pubmed_cite_options[pmc]' type='checkbox' value='1' />";
// 		  }
// 	}
//
// 	function pubmed_cite_setting_pm() {
// 		$options = get_option( 'pubmed_cite_options' );
// 		 if(!empty($options['pm'])){
// 			echo "<input id='pubmed_cite_setting_pm' name='pubmed_cite_options[pm]' type='checkbox' value='1' ". checked( 1, $options['pm'], false ) ."/>";
// 		  } else {
// 			echo "<input id='pubmed_cite_setting_pm' name='pubmed_cite_options[pm]' type='checkbox' value='1' />";
// 		  }
// 	}





//add_shortcode('pubmed-citations', 'pubmed_citations');
//add_action('admin_menu','pubmed_cite_options_page');
//add_action( 'admin_init','pubmed_cite_register_settings' );

 ?>
